@@ -16,8 +16,10 @@
 module FunBot.Sources
     ( feedWatcherSource
     , webListenerSource
+    , loopbackSource
     )
 where
 
 import FunBot.Sources.FeedWatcher (feedWatcherSource)
 import FunBot.Sources.WebListener (webListenerSource)
+import FunBot.Sources.Loopback (loopbackSource)
